import { createRouter, createWebHistory } from 'vue-router';
import store from '@/stores/counter';
import axios from 'axios';
const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      redirect: '/login'
    },
    {
      path: '/login',
      name: 'login',
      meta: { title: '耗材管理系统-账号登录' },
      component: () => import('@/views/login/index.vue')
    },
    {
      path: '/homeIndex',
      meta: { title: '耗材管理系统-系统首页' },
      component: () => import('@/components/admin-frame/home.vue'),
      children: [
        {
          path: '/homeIndex',
          meta: { title: '耗材管理系统-系统首页' },
          component: () => import('@/views/home/index.vue')
        },
        {
          path: '/users/one',
          meta: { title: '街道管理员' },
          component: () => import('@/views/users/one/index.vue')
        },
        {
          path: '/users/two',
          meta: { title: '厂商' },
          component: () => import('@/views/users/two/index.vue')
        },
        {
          path: '/users/thr',
          meta: { title: '街道人员' },
          component: () => import('@/views/users/thr/index.vue')
        },
        {
          path: '/users/four',
          meta: { title: '社区人员' },
          component: () => import('@/views/users/four/index.vue')
        },
        {
          path: '/users/five',
          meta: { title: '会计' },
          component: () => import('@/views/users/five/index.vue')
        },
        {
          path: '/users/six',
          meta: { title: '领导' },
          component: () => import('@/views/users/six/index.vue')
        },
        {
          path: '/users/detail',
          meta: { title: '信息管理' },
          component: () => import('@/views/users/detail/index.vue')
        },
        {
          path: '/way/street',
          meta: { title: '街道管理' },
          component: () => import('@/views/way/street.vue')
        },
        {
          path: '/way/community',
          meta: { title: '社区管理' },
          component: () => import('@/views/way/community.vue')
        },
        {
          path: '/goods/index',
          meta: { title: '商品管理' },
          component: () => import('@/views/goods/index.vue')
        },
        {
          path: '/spec/index',
          meta: { title: '规格管理' },
          component: () => import('@/views/spec/index.vue')
        },
        {
          path: '/order/index',
          meta: { title: '订单管理' },
          component: () => import('@/views/order/index.vue')
        },
        {
          path: '/order/detail',
          meta: { title: '订单信息管理' },
          component: () => import('@/views/order/detail.vue')
        },
        {
          path: '/system/buy',
          meta: { title: '采购审批设置' },
          component: () => import('@/views/system/buy/index.vue')
        },
        {
          path: '/system/config',
          meta: { title: '基础设置' },
          component: () => import('@/views/system/config/index.vue')
        },
        {
          path: '/system/dict',
          meta: { title: '字典管理' },
          component: () => import('@/views/system/dict/index.vue')
        },
        {
          path: '/system/dictData',
          meta: { title: '字典数据管理' },
          component: () => import('@/views/system/dictData/index.vue')
        },
        {
          path: '/system/module',
          meta: { title: '首页模块设置' },
          component: () => import('@/views/system/module/index.vue')
        },
        {
          path: '/system/money',
          meta: { title: '回款审批设置' },
          component: () => import('@/views/system/money/index.vue')
        },
        {
          path: '/system/role',
          meta: { title: '角色设置' },
          component: () => import('@/views/system/role/index.vue')
        },
        {
          path: '/system/role/detail',
          meta: { title: '角色信息管理' },
          component: () => import('@/views/system/role/detail.vue')
        },
        {
          path: '/acccount/updatepd',
          meta: { title: '修改密码' },
          component: () => import('@/views/updatepd/index.vue')
        }
      ]
    }
  ]
});
router.beforeEach(async (to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.name != 'login') {
    if (token) {
      const res = await axios.request({
        method: 'get',
        url: '/material/v1/api/tool/token',
        responseType: 'json',
        headers: {
          token: token
        }
      });
      if (res.data.errcode == '0') {
        store.commit('setUser', res.data.data, { root: true });
      }
      next();
    } else next('/login');
  } else next();
});

export default router;
